+++
title = "ox-hugo Issue 333 test"
description = "Description-less link an `https` image link."
tags = ["issues"]
draft = false
+++

`ox-hugo` Issue #[333](https://github.com/kaushalmodi/ox-hugo/issues/333)

{{< figure src="https://ox-hugo.scripter.co/test/ox-hugo/org.png" >}}
